select distinct
  "Datum",
  "ISIL",
  "Nummer",
  "Titel",
  "Aufsatztitel",
  "Autor",
  "Verlag",
  "ISBN",
  "ISSN",
  "Jahr",
  "Seiten",
  "Modus" from (
select
  to_char(h.oh_timepoint, 'DD.MM.YYYY') as "Datum",
  sup.it_isil as "ISIL",
  o.or_tan as "Nummer",
  s.st_itm_title  as "Titel",
  s.st_itm_art_title as "Aufsatztitel",
  s.st_itm_art_author as "Autor",
  case when s.st_itm_publisher is NULL then '' else s.st_itm_publisher || ', ' end || st_itm_publ_place  as "Verlag",
  s.st_itm_isn as "ISBN",
  s.st_itm_isn as "ISSN",
  s.st_itm_publ_date_comp as "Jahr",
  trim(case
    when s.st_itm_vol_issue is NULL then ''
    else 'Band/Heft ' || s.st_itm_vol_issue || ' '
  end || 'Seiten ' || s.st_itm_pagination) as "Seiten",
  case
    when e1.ref is NOT NULL then
      case
        when req.it_isil = 'DE-576' then 'U'
        when req.it_isil = 'DE-601' then 'U'
        when req.it_isil = 'DE-602' then 'U'
        when req.it_isil = 'DE-603' then 'U'
        when req.it_isil = 'DE-604' then 'U'
        when req.it_isil = 'DE-605' then 'U'
        else 'E'
      end
    else 'P'
  end as "Modus"
from
  medea3.orders o
  inner join medea3.stages s on o.or_id = s.st_or_id and o.or_seqno = s.st_seqno
  inner join medea3.orderhist h on o.or_id = h.oh_or_id and h.oh_id = (select max(oh_id) from medea3.orderhist where oh_or_id = o.or_id)
  inner join medea3.institutions req ON s.st_src_inst = req.it_id
  inner join medea3.institutions sup ON s.st_dest_inst = sup.it_id
  left outer join zflleihe50.event e1 on o.or_id = e1.ordernumber and e1.type = 'ack' and e1.code = 'membership-dd'
where
  o.or_status in (5,9,17,18)
  and sup.it_type in ('N','M','X')
  and sup.it_isil not in ('DE-576', 'DE-601', 'DE-602', 'DE-603', 'DE-604', 'DE-605')
  and req.it_isil not in ('DE-605')
  and s.st_type = 'K'
  and req.it_id != sup.it_id
  and h.oh_timepoint between to_date(:startdate, 'YYYY-MM-DD') and to_date(:enddate, 'YYYY-MM-DD')
union
select
  stat.zf6date as "Datum",
  decode(sup.zf10isil,
      'SWB', 'DE-576',
      'GBV', 'DE-601',
      'KOBV', 'DE-602',
      'HEBIS', 'DE-603',
      'BVB', 'DE-604',
      'hbz', 'DE-605',
      sup.zf10isil) as "ISIL",
  trim(m.zf1pfl2afl) AS "Nummer",
  t.zf8titel as "Titel",
  t.zf8atitel as "Aufsatztitel",
  t.zf8aufsatzautor as "Autor",
  t.zf8verlag as "Verlag",
  decode(t.zf8isbn, NULL, '', t.zf8isbn) AS "ISBN",
  decode(t.zf8issn, NULL, '', t.zf8issn) AS "ISSN",
  to_number(regexp_substr(t.zf8jahr,'^[[::digit::]]+$')) AS "Jahr",
  trim(case when t.zf8band is NULL then '' else decode(t.zf8band, NULL, '', ' Band ' || t.zf8band) || decode(t.zf8heft, NULL, '', ' Heft ' || t.zf8heft || ' ') end || ' Seiten ' || t.zf8seiten) AS "Seiten",
  case when e1.ref is NOT NULL then
     decode(req.zf10isil,
      'SWB', 'U',
      'DE-576', 'U',
      'GBV', 'U',
      'DE-601', 'U',
      'KOBV', 'U',
      'DE-602', 'U',
      'HEBIS', 'U',
      'DE-603', 'U',
      'BVB', 'U',
      'DE-604', 'U',
      'hbz', 'U',
      'DE-605', 'U',
      'E')
     else 'P' end as "Modus"
from
  zflleihe50.zf1medien m
  inner join zflleihe50.zf6status stat on m.zf1bestellid = stat.zf6bestellid and m.zf1lfd = stat.zf6lfd
  inner join zflleihe50.zf8titel t on m.zf1bestellid = t.zf8bestellid
  inner join zflleihe50.zf10bibl sup on stat.zf6sigelaktuell_id = sup.zf10id
  inner join zflleihe50.zf10bibl req on m.zf1sigelnb_id = req.zf10id
  left outer join zflleihe50.event e1 on m.zf1bestellid = e1.ordernumber and e1.type = 'ack' and e1.code = 'membership-dd'
where
  m.zf1bstype2 = 'C'
  and 'Shipped' = trim(stat.zf6vorgang)
  and sup.zf10isil != req.zf10isil
  and sup.zf10isil not in ('SWB', 'DE-576', 'GBV', 'DE-601', 'KOBV',  'DE-602', 'HEBIS', 'DE-603', 'BVB', 'DE-604', 'hbz', 'DE-605')
  and req.zf10isil not in ('hbz', 'DE-605')
  and stat.zf6date between to_date(:startdate, 'YYYY-MM-DD') and to_date(:enddate, 'YYYY-MM-DD')
)
