select /*+ FIRST_ROWS(10) */
    row_number() over (order by o.or_id desc) as "pos",
    os.os_name as "ordersystem",
    decode(s.st_type,
      'K', 'COPY',
      'E', 'FORM',
      'S', 'SCAN',
    s.st_type) as "circulation",
    to_char(o.or_id) as "ordernumber",
    replace(substr(o.or_tan, -instr(reverse(o.or_tan), '::') + 1),'/','%2F') as "transactionid",
    replace(substr(o.or_tan, -instr(reverse(o.or_tan), '::') + 1),'/','%2F') as "externaltransactionnumber",
    o.or_when as "ordertime",
    s.st_when as "lastactivitytime",
    case when o.or_status in (5,17) then s.st_when else null end as "supplytime",
    decode(sup.it_type,
      'N', 'INTERNAL',
      'M', 'INTERNAL',
      'I', 'INTERNAL',
      'X', 'DISABLED',
      'V', 'EXTERNAL',
    'INTERNAL') as "deliveryscope",
    decode(s.st_del_type,
      0, 'NONE',
      1, 'FAX',
      2, 'WWW',
      3, 'FTP',
      4, 'FTP',
      5, 'EMAIL',
      6, 'PRINT',
      7, 'NET',
      8, 'POST',
      9, 'INHOUSE',
      10, 'COLLECT',
      11, 'NETWORK',
      12, 'DISTANCELEARNING',
      13, 'PRINTINGSYSTEM',
      'UNDEFINED') as "deliverystyle",
    decode(req.it_type,
      'N', 'INTERNAL',
      'M', 'INTERNAL',
      'I', 'INTERNAL',
      'X', 'UNDEFINED',
      'V', 'EXTERNAL',
    'INTERNAL') as "notifymethod",
    decode(s.st_del_nf_type,
       0, 'NONE',
       1, 'EMAIL',
       2, 'POST',
       3, 'INHOUSE',
       4, 'FAX',
      'UNDEFINED') as "notifystyle",
    to_char(o.or_status) as "status",
    NULL as "substatus",
    sup.it_isil as "supplierisil",
    req.it_isil as "requesterisil",
    s.st_bennr as "clientid",
    s.st_ben1 as "clientname",
    o.or_note as "clientcomment",
    s.st_zuskosten as "maxcost",
    s.st_del_fetch_location as "pickuplocation",
    s.st_locname as "pickupcode",
    s.st_del_email as "clientemail",
    s.ST_DEL_NF_IM1 || chr(10) || s.ST_DEL_NF_IM2 || chr(10) || s.ST_DEL_NF_IM3 as "clientaddress",
    replace(o.or_ext_user_id,'/','%2F') as "externalrequester",
    s.st_del_mail_name2 || chr(10) || s.st_del_mail_street || chr(10) || s.st_del_mail_zip || ' ' || s.st_del_mail_city as "externaladdress",
    decode(s.st_type,
      'K', '2',
      'S', '2',
      'E', '9',
      NULL) as "priority",
    decode(e.time,
      NULL, -1,
    sysdate - cast(e.time as date)) as "deliveryage",
    o.or_num_pages as "pages",
    s.st_itm_art_author as "author",
    s.st_itm_art_title as "title",
    s.st_itm_title as "intitle",
    s.st_itm_publ_date_comp as "year",
    case when instr(s.st_itm_vol_issue, 'Band') > 0 then
        trim(regexp_substr(s.st_itm_vol_issue, 'Band(.*)Heft.*', 1, 1, NULL, 1))
    else
        s.st_itm_vol_issue
    end as "volume",
    case when instr(s.st_itm_vol_issue, 'Heft') > 0 then
        trim(regexp_substr(s.st_itm_vol_issue, '.*Heft(.*)', 1, 1, NULL, 1))
    else
        NULL
    end as "issue",
    s.st_itm_pagination as "pagination",
    s.st_itm_publisher as "publisher",
    s.st_itm_publ_place as "publisherplace",
    s.st_itm_isn as "isbn",
    '' as "issn",
    UPPER(s.st_itm_ver_ref_src) as "source",
    s.st_itm_uniq_id1 as "sourceid",
    e1.message as "doi",
    e2.ref as "directdelivery",
    e3.ref as "deliveryhash"
from medea3.orders o
    inner join medea3.ordersys os on o.or_os_id = os.os_id
    inner join medea3.stages s on o.or_id = s.st_or_id and o.or_seqno = s.st_seqno
    inner join medea3.institutions req on s.st_src_inst = req.it_id
    inner join medea3.institutions sup on s.st_dest_inst = sup.it_id
    left outer join zflleihe50.event e on o.or_id = e.ordernumber and e.type = 'transaction' and e.code = 'transaction-success'
    left outer join zflleihe50.event e1 on o.or_id = e1.ordernumber and e1.type = 'requestform' and e1.code = 'doi'
    left outer join zflleihe50.event e2 on o.or_id = e2.ordernumber and e2.type = 'ack' and e2.code = 'membership-dd'
    left outer join zflleihe50.event e3 on o.or_id = e3.ordernumber and e3.type = 'ack' and e3.code = 'hash'
